#######################
PyDMLabel
#######################

.. autoclass:: pydm.widgets.label.PyDMLabel
   :members:
   :show-inheritance:
   :exclude-members: DisplayFormat


.. note::
   See `QLabel Documentation <https://doc.qt.io/qtforpython-5/PySide2/QtWidgets/QLabel.html>`_ for all inherited properties and methods.